==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/



define("_PREVIOUS","Page Pr&eacute;c&eacute;dente");
define("_NEXT","Page Suivante");
define("_YOURNAME","Votre Nom");
define("_SORTASC","Tri croissant");
define("_SORTDESC","Tri d&eacute;croissant");

define("_CANCEL","Annuler");
define("_YES","Oui");
define("_NO","Non");

define("_SCORE","Score:");

define("_REPLYMAIN","Poster un commentaire");
define("_ALLOWEDHTML","HTML autoris&eacute;:");
define("_POSTANON","Publication anonyme");
define("_WRITEREVIEW","Ecrire un compte rendu");
define("_WRITEREVIEWFOR","Ecrire un compte rendu pour");
define("_ENTERINFO","Veuillez entrer les informations correspondantes aux sp&eacute;cifications");
define("_PRODUCTTITLE","Titre du produit");
define("_NAMEPRODUCT","Nom du produit examin&eacute;.");
define("_REVIEW","Compte rendu");
define("_CHECKREVIEW","Votre compte rendu actuel. Veuillez respecter une grammaire correcte! Utilisez au moins une centaine de mots, d'accord? Vous pouvez aussi employer les tags HTML si vous savez comment les utiliser.");
define("_FULLNAMEREQ","Votre nom complet. Requis.");
define("_REMAIL","Votre Email");
define("_REMAILREQ","Votre adresse e-mail. Requise.");
define("_SELECTSCORE","Score pour ce produit");
define("_RELATEDLINK","Lien en relation");
define("_PRODUCTSITE","Site Web officiel du produit. Assurez-vous que l'URL commence par \"http://\"");
define("_LINKTITLE","Titre du lien");
define("_LINKTITLEREQ","Requis si vous avez un lien associ&eacute;, optionnel sinon.");
define("_RIMAGEFILE","Nom du fichier image");
define("_RIMAGEFILEREQ","Nom de l'image de couverture, localis&eacute;e dans images/reviews/. Optionnel.");
define("_CHECKINFO","Veuillez vous assurer que l'information entr&eacute;e est 100% correcte et respecte la grammaire et la capitalisation. N'entrez pas votre texte enti&egrave;rement en majuscule: il sera rejet&eacute;.");
define("_INVALIDTITLE","Titre non valide... Ne peut pas &ecirc;tre &agrave; blanc");
define("_INVALIDSCORE","Score non valide... Doit &ecirc;tre compris entre 1 et 10");
define("_INVALIDTEXT","Texte de compte-rendu non valide... Ne peut pas &ecirc;tre &agrave; blanc");
define("_INVALIDHITS","Le nombre de hits doit &ecirc;tre un entier positif");
define("_CHECKNAME","Vous devez entrer ET votre nom, ET votre e-mail");
define("_INVALIDEMAIL","E-mail invalide (ex.: vous@yahoo.com)");
define("_INVALIDLINK","Vous devez entrer &agrave; la fois ET le titre du lien, ET l'URL du lien; ou laisser les 2 champs vides");
define("_ADDED","Ajout&eacute;:");
define("_REVIEWER","Critique:");
define("_REVIEWID","ID du compte rendu");
define("_HITS","Hits");
define("_LOOKSRIGHT","Ceci est-il correct ?");
define("_RMODIFIED","modifi&eacute;");
define("_RADDED","ajout&eacute;");

define("_ADMINLOGGED","Connect&eacute; en tant qu'administrateur... Ce compte rendu sera imm&eacute;diatement");
define("_RTHANKS","Merci pour votre proposition de compte rendu");
define("_MODIFICATION","modification");
define("_ISAVAILABLE","Il est maintenant disponible dans notre banque de donn&eacute;es.");
define("_EDITORWILLLOOK","Les &eacute;diteurs vont examiner votre compte rendu. Il sera disponible prochainement!");
define("_RBACK","Retour &agrave; l'index des comptes rendus");
define("_RWELCOME","Bienvenue dans la rubrique des comptes rendus");
define("_10MOSTPOP","10 comptes rendus les plus populaires");
define("_10MOSTREC","10 comptes rendus les plus r&eacute;cents");
define("_THEREARE","Il y a");
define("_REVIEWSINDB","comptes rendus dans la base de donn&eacute;es.");
define("_REVIEWS","Comptes rendus");
define("_REVIEWSLETTER","Comptes rendus pour la lettre");
define("_NOREVIEWS","Il n'y a pas de comptes rendus pour la lettre");
define("_TOTALREVIEWS","Total des comptes rendus trouv&eacute;s.");
define("_RETURN2MAIN","Retour au menu principal");
define("_REVIEWCOMMENT","Commentaire sur le compte rendu:");
define("_YOURNICK","Votre pseudo:");
define("_RCREATEACCOUNT","<a href=\"user.php\">Cr&eacute;er</a> un compte");
define("_YOURCOMMENT","Votre commentaire:");
define("_MYSCORE","Mon score:");

define("_REVIEWMOD","Modification du compte rendu");
define("_RDATE","Date:");
define("_RTITLE","Titre:");
define("_RTEXT","Texte:");
define("_REVEMAIL","E-mail:");
define("_RLINK","Lien:");
define("_RLINKTITLE","Titre du lien:");
define("_COVERIMAGE","Image de couverture:");
define("_PREMODS","Pr&eacute;visualisation des modifications");
define("_PAGE","Page");
define("_PAGEBREAK","Si vous voulez plusieurs pages, vous pouvez &eacute;crire <b>&lt;!--pagebreak--&gt;</b> l&agrave; o&ugrave; vous voulez un saut de page.");
define("_PREVIEW","Prvisualisation");
define("_LANGUAGE","Langue");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/



define("_PREVIOUS","Page Pr&eacute;c&eacute;dente");
define("_NEXT","Page Suivante");
define("_YOURNAME","Votre Nom");
define("_SORTASC","Tri croissant");
define("_SORTDESC","Tri d&eacute;croissant");

define("_CANCEL","Annuler");
define("_YES","Oui");
define("_NO","Non");

define("_SCORE","Score:");

define("_REPLYMAIN","Poster un commentaire");
define("_ALLOWEDHTML","HTML autoris&eacute;:");
define("_POSTANON","Publication anonyme");
define("_WRITEREVIEW","Ecrire un compte rendu");
define("_WRITEREVIEWFOR","Ecrire un compte rendu pour");
define("_ENTERINFO","Veuillez entrer les informations correspondantes aux sp&eacute;cifications");
define("_PRODUCTTITLE","Titre du produit");
define("_NAMEPRODUCT","Nom du produit examin&eacute;.");
define("_REVIEW","Compte rendu");
define("_CHECKREVIEW","Votre compte rendu actuel. Veuillez respecter une grammaire correcte! Utilisez au moins une centaine de mots, d'accord? Vous pouvez aussi employer les tags HTML si vous savez comment les utiliser.");
define("_FULLNAMEREQ","Votre nom complet. Requis.");
define("_REMAIL","Votre Email");
define("_REMAILREQ","Votre adresse e-mail. Requise.");
define("_SELECTSCORE","Score pour ce produit");
define("_RELATEDLINK","Lien en relation");
define("_PRODUCTSITE","Site Web officiel du produit. Assurez-vous que l'URL commence par \"http://\"");
define("_LINKTITLE","Titre du lien");
define("_LINKTITLEREQ","Requis si vous avez un lien associ&eacute;, optionnel sinon.");
define("_RIMAGEFILE","Nom du fichier image");
define("_RIMAGEFILEREQ","Nom de l'image de couverture, localis&eacute;e dans images/reviews/. Optionnel.");
define("_CHECKINFO","Veuillez vous assurer que l'information entr&eacute;e est 100% correcte et respecte la grammaire et la capitalisation. N'entrez pas votre texte enti&egrave;rement en majuscule: il sera rejet&eacute;.");
define("_INVALIDTITLE","Titre non valide... Ne peut pas &ecirc;tre &agrave; blanc");
define("_INVALIDSCORE","Score non valide... Doit &ecirc;tre compris entre 1 et 10");
define("_INVALIDTEXT","Texte de compte-rendu non valide... Ne peut pas &ecirc;tre &agrave; blanc");
define("_INVALIDHITS","Le nombre de hits doit &ecirc;tre un entier positif");
define("_CHECKNAME","Vous devez entrer ET votre nom, ET votre e-mail");
define("_INVALIDEMAIL","E-mail invalide (ex.: vous@yahoo.com)");
define("_INVALIDLINK","Vous devez entrer &agrave; la fois ET le titre du lien, ET l'URL du lien; ou laisser les 2 champs vides");
define("_ADDED","Ajout&eacute;:");
define("_REVIEWER","Critique:");
define("_REVIEWID","ID du compte rendu");
define("_HITS","Hits");
define("_LOOKSRIGHT","Ceci est-il correct ?");
define("_RMODIFIED","modifi&eacute;");
define("_RADDED","ajout&eacute;");

define("_ADMINLOGGED","Connect&eacute; en tant qu'administrateur... Ce compte rendu sera imm&eacute;diatement");
define("_RTHANKS","Merci pour votre proposition de compte rendu");
define("_MODIFICATION","modification");
define("_ISAVAILABLE","Il est maintenant disponible dans notre banque de donn&eacute;es.");
define("_EDITORWILLLOOK","Les &eacute;diteurs vont examiner votre compte rendu. Il sera disponible prochainement!");
define("_RBACK","Retour &agrave; l'index des comptes rendus");
define("_RWELCOME","Bienvenue dans la rubrique des comptes rendus");
define("_10MOSTPOP","10 comptes rendus les plus populaires");
define("_10MOSTREC","10 comptes rendus les plus r&eacute;cents");
define("_THEREARE","Il y a");
define("_REVIEWSINDB","comptes rendus dans la base de donn&eacute;es.");
define("_REVIEWS","Comptes rendus");
define("_REVIEWSLETTER","Comptes rendus pour la lettre");
define("_NOREVIEWS","Il n'y a pas de comptes rendus pour la lettre");
define("_TOTALREVIEWS","Total des comptes rendus trouv&eacute;s.");
define("_RETURN2MAIN","Retour au menu principal");
define("_REVIEWCOMMENT","Commentaire sur le compte rendu:");
define("_YOURNICK","Votre pseudo:");
define("_RCREATEACCOUNT","<a href=\"user.php\">Cr&eacute;er</a> un compte");
define("_YOURCOMMENT","Votre commentaire:");
define("_MYSCORE","Mon score:");

define("_REVIEWMOD","Modification du compte rendu");
define("_RDATE","Date:");
define("_RTITLE","Titre:");
define("_RTEXT","Texte:");
define("_REVEMAIL","E-mail:");
define("_RLINK","Lien:");
define("_RLINKTITLE","Titre du lien:");
define("_COVERIMAGE","Image de couverture:");
define("_PREMODS","Pr&eacute;visualisation des modifications");
define("_PAGE","Page");
define("_PAGEBREAK","Si vous voulez plusieurs pages, vous pouvez &eacute;crire <b>&lt;!--pagebreak--&gt;</b> l&agrave; o&ugrave; vous voulez un saut de page.");
define("_PREVIEW","Prvisualisation");
define("_LANGUAGE","Langue");


?>
